@@ -34,46 +34,92 @@ default_loop_function = function(instance) {
   }
 }
 
+#' @title Default Gaussian Process
+#'
+#' @description
+#' This is a helper function that constructs a default Gaussian Process [mlr3::LearnerRegr] which is for example used in
+#' [default_surrogate].
+#'
+#' Constructs a Kriging learner \dQuote{"regr.km"} with kernel \dQuote{"matern5_2"}.
+#' If \code{noisy = FALSE} (default) a small nugget effect is added \code{nugget.stability = 10^-8} to increase
+#' numerical stability to hopefully prevent crashes of \CRANpkg{DiceKriging}.
+#' If \code{noisy = TRUE} the nugget effect will be estimated with \code{nugget.estim = TRUE}.
+#' If \code{noisy = TRUE} \code{jitter} is set to \code{TRUE} to circumvent a problem with \CRANpkg{DiceKriging} where
+#' already trained input values produce the exact trained output.
+#' In general, instead of the default \code{"BFGS"} optimization method we use rgenoud (\code{"gen"}), which is a hybrid
+#' algorithm, to combine global search based on genetic algorithms and local search based on gradients.
+#' This may improve the model fit and will less frequently produce a constant model prediction.
+#'
+#' @param noisy (logical(1))\cr
+#'   Whether the learner will be used in a noisy objective function scenario.
+#'   See above.
+#' @return [mlr3::LearnerRegr]
+#' @family mbo_defaults
+#' @export
+default_gp = function(noisy = FALSE) {
+  assert_flag(noisy)
+  require_namespaces("mlr3learners")
+  require_namespaces("DiceKriging")
+  require_namespaces("rgenoud")
+  learner = mlr3learners::LearnerRegrKM$new()
+  learner$param_set$values = insert_named(
+    learner$param_set$values,
+    list(covtype = "matern5_2", optim.method = "gen", control = list(trace = FALSE))
+  )
+  if (noisy) {
+    learner$param_set$values = insert_named(learner$param_set$values, list(nugget.estim = TRUE, jitter = 1e-12))
+  } else {
+    learner$param_set$values = insert_named(learner$param_set$values, list(nugget.stability = 10^-8))
+  }
+  learner
+}
+
+#' @title Default Random Forest
+#'
+#' @description
+#' This is a helper function that constructs a default random forest [mlr3::LearnerRegr] which is for example used in
+#' [default_surrogate].
+#'
+#' Constructs a ranger learner \dQuote{"regr.ranger"} with \code{num.trees = 100}, \code{keep.inbag = TRUE} and
+#' \code{se.method = "jack"}.
+#'
+#' @param noisy (logical(1))\cr
+#'   Whether the learner will be used in a noisy objective function scenario.
+#'   Currently has no effect.
+#' @return [mlr3::LearnerRegr]
+#' @family mbo_defaults
+#' @export
+default_rf = function(noisy = FALSE) {
+  assert_flag(noisy)
+  require_namespaces("mlr3learners")
+  require_namespaces("ranger")
+  learner = mlr3learners::LearnerRegrRanger$new()
+  learner$param_set$values = insert_named(
+    learner$param_set$values,
+    list(num.trees = 100L, keep.inbag = TRUE, se.method = "jack")
+  )
+  learner
+}
+
 #' @title Default Surrogate
 #'
 #' @description
-#' This is a helper function that generates a default [Surrogate] based on properties of the
+#' This is a helper function that constructs a default [Surrogate] based on properties of the
 #' [bbotk::OptimInstance].
 #'
-#' For numeric-only (including integers) parameter spaces without any dependencies:
-#' \itemize{
-#' \item{A Kriging model \dQuote{"regr.km"} with kernel \dQuote{"matern3_2"} is created.}
-#' \item{If the objective function is deterministic we add a small nugget effect (10^-8*Var(y),
-#'   y is vector of observed outcomes in current design) to increase numerical stability to
-#'   hopefully prevent crashes of \CRANpkg{DiceKriging}.
-#'   Whether the objective function is deterministic can be observed from the objective function's
-#'   properties.}
-#' \item{If the objective function is noisy the nugget effect will be estimated with
-#'   \code{nugget.estim = TRUE}.}
-#' \item{Also \code{jitter} is set to \code{TRUE} to circumvent a problem with \CRANpkg{DiceKriging}
-#'   where already trained input values produce the exact trained output.
-#'   Whether the objective function is noisy can be observed from the objective functions
-#'   properties.}
-#' \item{Instead of the default \code{"BFGS"} optimization method we use rgenoud (\code{"gen"}),
-#'   which is a hybrid algorithm, to combine global search based on genetic algorithms and local search
-#'   based on gradients.
-#'   This may improve the model fit and will less frequently produce a constant surrogate model.}
-#' }
+#' For numeric-only (including integers) parameter spaces without any dependencies a Gaussian Process is constricted via
+#' [default_gp()].
+#' For mixed numeric-categorical parameter spaces, or spaces with conditional parameters a random forest is constructed via
+#' [default_rf()].
 #'
-#' For mixed numeric-categorical parameter spaces, or spaces with conditional parameters:
-#' \itemize{
-#' \item{A ranger regression forest \dQuote{"regr.ranger"} with 500 trees is created.}
-#' \item{The standard error of a prediction (if required by the infill criterion) is estimated via jackknife.
-#'   This is the \code{se.method = "jack"} option of the \dQuote{"regr.ranger"} learner (default).
-#'   }
-#' }
 #' In any case, learners are encapsulated using \dQuote{"evaluate"}, and a fallback learner is set,
-#' in cases where the surrogate learner errors. Currently, the following learner is used as a fallback:
-#' \code{lrn("regr.ranger", num.trees = 20L, keep.inbag = TRUE, se.method = "jack")}.
+#' in cases where the surrogate learner errors.
+#' Currently, the following learner is used as a fallback:
+#' \code{lrn("regr.ranger", num.trees = 10L, keep.inbag = TRUE, se.method = "jack")}.
 #'
 #' If additionally dependencies are present in the parameter space, inactive conditional parameters
 #' are represented by missing \code{NA} values in the training design data.
-#' We simply handle those with an imputation method, added to the ranger random forest, more
+#' We simply handle those with an imputation method, added to the random forest, more
 #' concretely we use \code{po("imputesample")} (for logicals) and \code{po("imputeoor")} (for anything else) from
 #' package \CRANpkg{mlr3pipelines}.
 #' Characters are always encoded as factors via \code{po("colapply")}.
@@ -84,7 +130,7 @@ default_loop_function = function(instance) {
 #' If the instance is of class [bbotk::OptimInstanceSingleCrit] the learner is wrapped as a
 #' [SurrogateLearner].
 #'
-#' If the instance is of class [bbotk::OptimInstanceMultiCrit] deep clones of the learner are
+#' If the instance is of class [bbotk::OptimInstanceMultiCrit] multiple deep clones of the learner are
 #' wrapped as a [SurrogateLearnerCollection].
 #'
 #' @references
@@ -93,7 +139,10 @@ default_loop_function = function(instance) {
 #' @param instance ([bbotk::OptimInstance])\cr
 #'   An object that inherits from [bbotk::OptimInstance].
 #' @param learner (`NULL` | [mlr3::Learner]).
+#'   If specified, this learner will be used instead of the defaults described above.
 #' @param n_learner (`NULL` | `integer(1)`).
+#'  Number of learners to be considered in the construction of the [SurrogateLearner] or [SurrogateLearnerCollection].
+#'  If not specified will be based on the number of objectives as stated by the instance.
 #' @return [Surrogate]
 #' @family mbo_defaults
 #' @export
@@ -101,38 +150,23 @@ default_surrogate = function(instance, learner = NULL, n_learner = NULL) {
   assert_r6(instance, "OptimInstance")
   assert_r6(learner, "Learner", null.ok = TRUE)
   assert_int(n_learner, lower = 1L, null.ok = TRUE)
+  noisy = "noisy" %in% instance$objective$properties
 
   if (is.null(learner)) {
     is_mixed_space = !all(instance$search_space$class %in% c("ParamDbl", "ParamInt"))
     has_deps = nrow(instance$search_space$deps) > 0L
-    require_namespaces("mlr3learners")
-    if (!is_mixed_space) {
-      require_namespaces("DiceKriging")
-      learner = mlr3learners::LearnerRegrKM$new()
-      learner$param_set$values = insert_named(
-        learner$param_set$values,
-        list(covtype = "matern3_2", optim.method = "gen", control = list(trace = FALSE))
-      )
-      if ("noisy" %in% instance$objective$properties) {
-        learner$param_set$values = insert_named(learner$param_set$values, list(nugget.estim = TRUE, jitter = 1e-12))
-      } else {
-        learner$param_set$values = insert_named(learner$param_set$values, list(nugget.stability = 10^-8))
-      }
+    learner = if (!is_mixed_space) {
+      default_gp(noisy)
     } else {
-      require_namespaces("ranger")
-      learner = mlr3learners::LearnerRegrRanger$new()
-      learner$param_set$values = insert_named(
-        learner$param_set$values,
-        list(num.trees = 500L, keep.inbag = TRUE, se.method = "jack")
-      )
+      default_rf(noisy)
     }
-    # Stability: evaluate and add a fallback
+    # stability: evaluate and add a fallback
     learner$encapsulate[c("train", "predict")] = "evaluate"
     require_namespaces("ranger")
     fallback = mlr3learners::LearnerRegrRanger$new()
     fallback$param_set$values = insert_named(
       fallback$param_set$values,
-      list(num.trees = 20L, keep.inbag = TRUE, se.method = "jack")
+      list(num.trees = 10L, keep.inbag = TRUE, se.method = "jack")
     )
     learner$fallback = fallback
 
