@@ -44,7 +44,7 @@ test_that("Constructing TunerMbo and ABs", {
   expect_identical(tuner$acq_function, optimizer$acq_function)
   expect_identical(tuner$acq_optimizer, optimizer$acq_optimizer)
   expect_identical(tuner$args, optimizer$args)
-  expect_identical(tuner$result_function, optimizer$result_function)
+  expect_identical(tuner$result_assigner, optimizer$result_assigner)
   expect_identical(tuner$param_classes, optimizer$param_classes)
   expect_identical(tuner$properties, optimizer$properties)
   expect_identical(tuner$packages, optimizer$packages)
@@ -56,7 +56,7 @@ test_that("Constructing TunerMbo and ABs", {
   expect_identical(tuner$acq_function, optimizer$acq_function)
   expect_identical(tuner$acq_optimizer, optimizer$acq_optimizer)
   expect_identical(tuner$args, optimizer$args)
-  expect_identical(tuner$result_function, optimizer$result_function)
+  expect_identical(tuner$result_assigner, optimizer$result_assigner)
   expect_identical(tuner$param_classes, optimizer$param_classes)
   expect_identical(tuner$properties, optimizer$properties)
   expect_identical(tuner$packages, optimizer$packages)
